SpDust — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- SpDust

# SpDust

class `pysm.` `SpDust`(map_I, freq_ref_I, emissivity, freq_peak, freq_ref_peak, nside, unit_I=None, map_dist=None)

  Bases: `pysm.Model`

  Implementation of the SpDust2 code of (Ali-Haimoud et al 2012) evaluated for a Cold Neutral Medium. See: * https://arxiv.org/abs/1003.4732 * https://arxiv.org/abs/0812.2904

  This function initializes the spinning dust model

  Parameters
    map_I `pathlib.Path` object

      Paths to the map to be used as I templates.

    unit_Istring or Unit

      Unit string or Unit object for all input FITS maps, if None, the input file should have a unit defined in the FITS header.

    freq_ref_IQuantity or string

      Reference frequencies at which the templates are defined. They should be a astropy Quantity object or a string (e.g. “1500 MHz”) compatible with GHz.

    freq_peak `pathlib.Path` object or string

      Path to the map to be used as frequency of the peak of the emission or its scalar value as a Quantity or a string convertible to a Quantity

    freq_ref_peakQuantity or string

      Reference frequency for the peak frequency map They should be a astropy Quantity object or a string (e.g. “1500 MHz”) compatible with GHz.

    nside: int

      Resolution parameter at which this model is to be calculated.

  Methods Summary

  `get_emission`(self, freqs[, weights]) | This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None)

    This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

    Parameters
      freqs: float

        Frequency at which the model should be evaluated, assumed to be given in GHz.

    Returns
      ndarray

        Set of maps at the given frequency or frequencies. This will have shape (nfreq, 3, npix).